@@ -1,12 +1,16 @@
-import os
 import json
+import os
 from shutil import copyfile, rmtree
-from docker.tls import TLSConfig
+
 from docker.errors import ContextException
-from docker.context.config import get_meta_dir
-from docker.context.config import get_meta_file
-from docker.context.config import get_tls_dir
-from docker.context.config import get_context_host
+from docker.tls import TLSConfig
+
+from .config import (
+    get_context_host,
+    get_meta_dir,
+    get_meta_file,
+    get_tls_dir,
+)
 
 
 class Context:
